class Api::TransferSpecsController < Api::BaseController
  include Api::RequestParamParsing

  skip_before_filter :authenticate, only: [:get_transfer_spec]
  before_filter :authenticate_allow_external, only: [:get_transfer_spec]

  def get_transfer_spec

    begin
      parse_user # mix in
      parse_delivery # mix in

      # handle paths in request JSON
      paths = params[:paths] || ['/']

      case parse_direction

        when ESession::DIRECTION_UPLOAD

          begin

            spec = @delivery.upload_spec_for_user(@user,
                                                  request.remote_ip,
                                                  request.host,
                                                  paths)

          rescue Delivery::TransferSpecError => e

            raise Api::BadRequestError.new(
                      "Error creating upload spec: #{e.message}.",
                      'Upload failed'
                  )

          end

        when ESession::DIRECTION_DOWNLOAD


          begin

            spec = @delivery.download_spec_for_user(@user,
                                                    request.remote_ip,
                                                    request.host,
                                                    params[:share_id_order],
                                                    paths)

          rescue Delivery::TransferSpecError => e

            raise Api::BadRequestError.new(
                      "Error creating download spec: #{e.message}.",
                      'Download failed'
                  )

          end

      end

      if (!params[:skip_recalculation].nil? && !params[:skip_recalculation]) &&
          ((parse_direction == ESession::DIRECTION_UPLOAD) && (@delivery.e_package.e_sessions.length != 0))
          (@delivery.e_package.e_sessions.length != 0)

          @delivery.e_package.queue_recalculation(1, false)
      end

      respond_to do |format|
        format.json do
          render json: spec
        end
      end
    rescue => ex
      rescue_with_handler(ex) || raise
    end
  end

  def issue_token
    parse_user # mix in
    parse_delivery # mix in

    send = params[:direction].to_s.downcase != 'receive'

    if send
      if params[:paths].present?
        raise Api::BadRequestError, "Source paths must be a list" unless params[:paths].is_a?(Array)
        paths = params[:paths]
      elsif params[:destination].present?
        paths = [params[:destination]]
      else
        paths = ['/']
      end

      paths = { paths: paths.map{ |path| {destination: @delivery.node_path(path)} } }

      response = @delivery.storage_share.node.api_client.upload(paths)
    else
      if params[:paths].present?
        raise Api::BadRequestError, "Source paths must be a list" unless params[:paths].is_a?(Array)

        paths = params[:paths]
      elsif params[:source].present?
        raise Api::BadRequestError, "Source paths must be a list" unless params[:source].is_a?(Array)

        paths = params[:source]
      else
        paths =['/']
      end

      paths = { paths: paths.map{ |path| {source: @delivery.node_path(path)} } }

      response = @delivery.storage_share.node.api_client.download(paths)
    end

    respond_to do |format|
      error = response.response_parsed['transfer_specs'].first['error'].present?

      format.json do
        if error
          response = response.response_parsed['transfer_specs'].first['error']
          raise Api::Error.new(
            response['code'],
            "Error generating token: #{response['user_message']}",
            "Error generating token: #{response['user_message']}"
          )
        else
          response = response.response_parsed['transfer_specs'].first['transfer_spec']

          if send
            render json: {
              destination_root: response['destination_root'],
              token: response['token']
            }
          else
            render json: {
              paths: response['paths'],
              token: response['token']
            }
          end
        end
      end
    end
  end


  private

  def parse_direction
    case params[:direction]
      when 'send'
        ESession::DIRECTION_UPLOAD
      when 'receive'
        ESession::DIRECTION_DOWNLOAD
      else
        raise Api::BadRequestError,
              "Missing or bad direction param <#{params[:direction]}>."
    end
  end

end
