module BootstrapContentHelper
  def bulk_menu(labels_map)
    return '' if labels_map.empty?
    content_tag :div, class: 'btn-group' do
      content_tag(:a, class: 'btn dropdown-toggle', "data-toggle" => 'dropdown', "href" => "#dropdown-menu") do
        t('app.helpers.account.bootstrap_content_helper.actions') + content_tag(:span, nil, class: 'caret')
      end +
      content_tag(:ul, class: 'dropdown-menu') do
        labels_map.map do |k,v|
          content_tag :li do
            if k.downcase == "remove"
              link_to_function v, "if (confirm('Are you sure?')) { jQuery('#bulk_action').val('#{k.underscore}'); jQuery('#bulk_form').submit() }"
            else
              link_to_function v, "jQuery('#bulk_action').val('#{k.underscore}'); jQuery('#bulk_form').submit()"
            end
          end
        end.join
      end
    end
  end

  def dropdown_menu_html(dropboxes)
    return "" if dropboxes.empty?
    dropdown_menu_html = "<div id='new_package_menu' class='popup_menu view_menu drop_shadow' style='display:none; top: 93px; left: 0px; '><ul>"
    if current_user.uploads_allowed? && current_user.allowed_to_send_normal_packages?
      dropdown_menu_html << "<li><a href='#{(controller.controller_name == 'send' && controller.action_name == 'new') ? '#' : url_for(:controller => '/send', :action => :new)}' id='new_dropbox_normal_pkg'>Normal Package</a></li>"
    end
    dropboxes.each { |dbox|
      dropdown_menu_html << "<li><a href='#{new_dropbox_delivery_path(dbox)}' id='new_dropbox_pkg_#{dbox.id}'>#{h dbox.e_wg_name}</a></li>"
    }
    dropdown_menu_html << '</ul></div>'
  end

  def btn_toolbar &block
    concat(content_tag(:div, class: 'btn-toolbar') do
      capture &block
    end)
  end

  def btn_group &block
    concat(content_tag(:div, class: 'btn-group') do
      capture &block
    end)
  end

  %w[info error success warning].each do |alert_type|
    define_method("alert_#{alert_type}") do |&block|
      concat(content_tag(:div, class: "alert alert-#{alert_type}") do
        capture &block
      end)
    end
  end

  def alert_block_error heading, &block
    concat(content_tag(:div, class: 'alert alert-block alert-error') do
      content_tag(:h4, heading, class: 'alert-heading') + capture(&block)
    end)
  end

  def label_warning text
    content_tag :span, text, class: 'label label-warning'
  end

  def label_important text
    content_tag :span, text, class: 'label label-important'
  end

  ## TODO - replace partial to handle a block
  def modal header, partial, options = {}, partial_options = {}
    options[:link_content] ||= header
    options[:modal_id] ||= 'foo'

    link_to(options[:link_content], "##{options[:modal_id]}", 'data-toggle' => 'modal', id: "#{header.parameterize('_')}_modal_link") +
    (content_tag :div, class: 'hide modal', role: 'dialog', "tabindex" => 0, "aria-labelledby" => "modalTitle_#{options[:modal_id]}", "aria-describedby" => "modalContent_#{options[:modal_id]}", id: options[:modal_id] do
      (content_tag :div, class: 'modal-dialog', role: 'document' do
        (content_tag :div, class: 'modal-header' do
          link_to('x', nil, class: 'close', "aria-label" => t('app.helpers.account.bootstrap_content_helper.close'), 'data-dismiss' => 'modal') + content_tag(:h3, header, id: "modalTitle_#{options[:modal_id]}")
        end) +

        (content_tag :div, class: 'modal-body' do
          render partial_options.merge(partial: partial)
        end) +

        (content_tag :div, class: 'modal-footer' do
          link_to 'Close', '#', class: 'btn', 'data-dismiss' => 'modal'
        end)
      end)
    end)
  end

  # HACK - hardcoded accordion id
  # TODO - force option to provide accordion id
  # TODO - this needs to be extracted to a module
  # Do not use two accordions on the same page
  def accordion &block
    concat(content_tag(:div, class: "accordion", id: "accordion2") do
      capture(self, &block)
    end)
  end

  def group title, partial, partial_options = {}, options = {}
    link_classes = 'accordion-toggle'

    body_id = "collapse_#{title.parameterize}"
    body_classes = 'accordion-body collapse'
    body_classes += 'in' if options.delete(:open)

    content_tag :div, class: 'accordion-group' do
      (content_tag :div, class: 'accordion-heading' do
        link_to title, "#" + body_id, class: link_classes, 'data-toggle' => 'collapse', 'data-parent' => '#accordion2'
      end) +
      (content_tag :div, id: body_id, class: body_classes do
        content_tag :div, class: 'accordion-inner' do
          render partial, partial_options
        end
      end)
    end
  end

  def horizontal_form_for record_or_name_or_array, *args, &proc
    options = args.extract_options!
    (options[:html] ||= {})[:class] = 'form-horizontal'
    stacked_form_for record_or_name_or_array, *(args << options), &proc
  end

  def stacked_form_for record_or_name_or_array, *args, &proc
    options = args.extract_options!
    form_for(record_or_name_or_array, *(args << options.merge(builder: Bootstrap::LabeledFormBuilder)), &proc)
  end

  # Backported from Rails 3
  def button_tag(content_or_options = nil, options = nil, &block)
    options = content_or_options if block_given? && content_or_options.is_a?(Hash)
    options ||= {}
    options[:class] ||= 'btn'

    options = options.stringify_keys

    if disable_with = options.delete("disable_with")
      ActiveSupport::Deprecation.warn ":disable_with option is deprecated and will be removed from Rails 4.0. Use 'data-disable-with' instead"

      options["data-disable-with"] = disable_with
    end

    if confirm = options.delete("confirm")
      ActiveSupport::Deprecation.warn ":confirm option is deprecated and will be removed from Rails 4.0. Use ':data => { :confirm => \'Text\' }' instead"

      options["data-confirm"] = confirm
    end

    options.reverse_merge! 'name' => 'button', 'type' => 'submit'

    content_tag :button, content_or_options || 'Button', options, &block
  end
end
